#
# spec file for package malcontent
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           malcontent
Version:        0.12.0
Release:        1.3
Summary:        Parental control system
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
URL:            https://gitlab.freedesktop.org/pwithnall/malcontent
Source:         https://tecnocode.co.uk/downloads/%{name}-%{version}.tar.xz

BuildRequires:  desktop-file-utils
BuildRequires:  itstool
BuildRequires:  meson >= 0.50.0
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(accountsservice) >= 0.6.39
BuildRequires:  pkgconfig(appstream-glib)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(flatpak)
BuildRequires:  pkgconfig(glib-2.0) >= 2.54.2
BuildRequires:  pkgconfig(glib-testing-0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(polkit-gobject-1)

%description
Libmalcontent implements parental controls support which can be
used by applications to filter or limit the access of child
accounts to inappropriate content.

%lang_package

%package -n libmalcontent-0-0
Summary:        Malcontent system library
Requires:       malcontent >= %{version}

%description -n libmalcontent-0-0
Libmalcontent implements parental controls support which can be
used by applications to filter or limit the access of child
accounts to inappropriate content.

%package -n typelib-1_0-Malcontent-0
Summary:        Introspection bindings for the malcontent system library

%description -n typelib-1_0-Malcontent-0
Libmalcontent implements parental controls support which can be
used by applications to filter or limit the access of child
accounts to inappropriate content.

%package -n libmalcontent-ui-1-1
Summary:        Malcontent UI library

%description -n libmalcontent-ui-1-1
Libmalcontent implements parental controls support which can be
used by applications to filter or limit the access of child
accounts to inappropriate content.

%package -n typelib-1_0-MalcontentUi-1
Summary:        Introspection bindings for the malcontent UI library

%description -n typelib-1_0-MalcontentUi-1
Libmalcontent implements parental controls support which can be
used by applications to filter or limit the access of child
accounts to inappropriate content.

%package devel
Summary:        Devel package
Requires:       libmalcontent-0-0 = %{version}
Requires:       libmalcontent-ui-1-1 = %{version}
Requires:       typelib-1_0-Malcontent-0 = %{version}
Requires:       typelib-1_0-MalcontentUi-1 = %{version}

%description devel
Libmalcontent implements parental controls support which can be
used by applications to filter or limit the access of child
accounts to inappropriate content.

%package control
Summary:        Parental Control Application
Requires:       malcontent >= %{version}

%description control
Parental Control management application for Malcontent

%prep
%autosetup -p1
sed -i 's|env python3|python3|' malcontent-client/malcontent-client.py

%build
%meson \
	-Dpamlibdir=%{_pam_moduledir}
	%{nil}
%meson_build

%install
%meson_install
# com.endlessm.ParentalControls.rules would allow 'wheel' group users access without polkit auth
# wheel is not used in openSUSE, so we simply package this file as an example %%doc file
mv %{buildroot}%{_datadir}/polkit-1/rules.d/com.endlessm.ParentalControls.rules .
%find_lang %{name}
%python3_fix_shebang

%ldconfig_scriptlets -n libmalcontent-0-0
%ldconfig_scriptlets  -n libmalcontent-ui-1-1

%files
%license COPYING
%doc NEWS README.md
%doc com.endlessm.ParentalControls.rules
%{_pam_moduledir}/pam_malcontent.so
%{_bindir}/malcontent-client
%{_mandir}/man8/malcontent-client.8%{?ext_man}
%{_datadir}/dbus-1/interfaces/com.endlessm.ParentalControls.*
%dir %{_datadir}/accountsservice
%dir %{_datadir}/accountsservice/interfaces
%{_datadir}/accountsservice/interfaces/com.endlessm.ParentalControl*
%{_datadir}/polkit-1/actions/com.endlessm.ParentalControls.policy
%{_datadir}/polkit-1/actions/org.freedesktop.MalcontentControl.policy

%files lang -f %{name}.lang

%files -n libmalcontent-0-0
%{_libdir}/libmalcontent-0.so.*

%files -n typelib-1_0-Malcontent-0
%{_libdir}/girepository-1.0/Malcontent-0.typelib

%files -n libmalcontent-ui-1-1
%{_libdir}/libmalcontent-ui-1.so.*

%files -n typelib-1_0-MalcontentUi-1
%{_libdir}/girepository-1.0/MalcontentUi-1.typelib

%files devel
%{_includedir}/%{name}-0/
%{_includedir}/%{name}-ui-1/
%{_libdir}/libmalcontent-0.so
%{_libdir}/libmalcontent-ui-1.so
%{_libdir}/pkgconfig/malcontent-0.pc
%{_libdir}/pkgconfig/malcontent-ui-1.pc
%{_datadir}/gir-1.0/Malcontent-0.gir
%{_datadir}/gir-1.0/MalcontentUi-1.gir

%files control
%{_bindir}/malcontent-control
%{_datadir}/metainfo/org.freedesktop.MalcontentControl.appdata.xml
%{_datadir}/icons/hicolor/*/apps/org.freedesktop.MalcontentControl*
%{_datadir}/applications/org.freedesktop.MalcontentControl.desktop

%changelog
* Wed May 15 2024 ming li <mli@suse.com>
- Update to 0.12.0:
  * Support searching list of apps to restrict
  * Keynav focus disappears after GTK4 port
  * Confusing sentence in user-controls.ui: above, below?
  * mct_app_filter_is_appinfo_allowed fails when desktop entry
    is missing Exec key
  * “All Ages” option for Application Suitability is misleading
  * Updated translations
  * Add AppInfo support to malcontent-client check-app-filter
  * update ru.po
  * data: Update appdata
  * build: Hide private structs from generated GIR files
  * Various build and dependency cleanups for GTK 4.12
  * malcontent-client: Fix syntax error in appinfo support
* Fri Mar 22 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Thu Oct 12 2023 Bjørn <bjorn.lie@gmail.com>
- Update to version 0.11.1:
  + Bugs fixed: build: Switch to Meson’s gnome.post_install
    function
  + Updated translations.
- Changes from version 0.11.0:
  + libmalcontent-ui, and the malcontent-control application, now
    use libappstream rather than appstream-glib.
  + libmalcontent-ui, and the malcontent-control application, now
    use GTK 4 and libadwaita rather than GTK+ 3.
  + As a result of these changes, the pkg-config name has been
    bumped to libmalcontent-ui-1, and the gobject-introspection
    name to MalcontentUi-1.
  + Improve keyboard navigation of the malcontent-control
    application.
  + Updated translations.
- Drop pkgconfig(gtk+-3.0) BuildRequires, and add
  desktop-file-utils, pkgconfig(gtk4) and pkgconfig(libadwaita-1)
  following upstream changes.
- Rename libmalcontent-ui-0-0, typelib-1_0-MalcontentUi-0 and
  typelib-1_0-MalcontentUi-0 to libmalcontent-ui-1-1,
  typelib-1_0-MalcontentUi-1 and typelib-1_0-MalcontentUi-1
  following upstream soname changes.
* Tue May 10 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.10.4
  + Remove superfluous arguments to i18n.merge_file.
  + Updated translations.
- Drop upstream resolved patch:
  + f433aaf8c8f82f0aeaedee664f08bc6fcad47b0d.patch
* Tue Feb  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.10.3:
  + Bugs fixed:
  - Do not make malcontent-control user uninstallable using gui
  - malcontent-control:
    . Fix an unterminated option entry array
    . Focus controls rather than user selector
  + Updated translations.
- Changes from version 0.10.2:
  + Hide the launcher for malcontent-control from gnome-shell if
    using the GNOME desktop; find it via gnome-control-center
    instead
  + Bugs fixed:
  - Limit depth of clone of subprojects
  - Rename master to main branch
  + Updated translations.
- Add f433aaf8c8f82f0aeaedee664f08bc6fcad47b0d.patch: Fix build
  with meson 0.61.0.
* Tue Sep 28 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%_pam_moduledir instead of harcoding %%{_lib}/security
  (boo#1191037).
* Mon May 31 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.10.1
  + Improve support for systems without accountsservice
  + Fix some data loss-causing state synchronisation problems
  + Hide support for flatpak user repositories, as they are
    typically not configured on systems
  + Add manpage docs for malcontent-client
  + Consider terminology of ‘parental controls’
  + Improving padding/spacing in malcontent-control UI
  + Reload ‘Restrict Apps’ list when installed apps change on system
  + Add command line option to malcontent-control to pre-select a user
  + Fails closed if accountsservice isn't available on the bus
  + Fix partial loss of parental controls settings when partially
    updating them
  + libmalcontent-ui: Drop handling of eos-link desktop files
  + user-controls: Only save the app filter if it’s changed
  + Add Danish translation
  + Update Ukrainian, Italian, Swedish, and Polish translation
* Thu Dec 10 2020 Stasiek Michalski <stasiek@michalski.cc>
- Split MalcontentControl into seperate package so a library
  doesn't require a desktop application.
* Wed Nov 18 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Don't actually install com.endlessm.ParentalControls.rules: this
  just grants 'wheel'-group members access without password; as
  openSUSE does not support 'wheel' by default, we only ship the
  file as sample file (boo#1177974#c8).
* Sat Oct 31 2020 Marcus Rueckert <mrueckert@suse.de>
- The library needs to require the daemon package as it is not
  usable without it. e.g. gnome-control-center -> applications wont
  list any informations.
* Sat Sep  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Initial package, version 0.9.0.
